@@ -1,15 +1,13 @@
 library(Polychrome)
 
-tem<- 1:12
-Polychrome:::xform(tem)
-
+tem <- tema <- 1:12
 names(tem) <- paste("C", 1:12, sep='')
-Polychrome:::xform(tem)
+all(Polychrome:::xform(tem) == Polychrome:::xform(tem))
 
 tem <- topo.colors(12, alpha=0.6)
 all(tem == Polychrome:::xform(tem, alpha=TRUE))
 
-suppressWarnings( RNGversion("3.5.3") )
+suppressWarnings( RNGversion("3.5.0") )
 set.seed(236746)
 tem <- sample(colors(), 12)
 Polychrome:::xform(tem)
